Package: ordinalsimr
Title: Compare Ordinal Endpoints Using Simulations
Version: 0.2.4
Authors@R: 
    person(given = "Pat",
           family = "Callahan",
           role = c("aut", "cre", "cph"),
           email = "patricktcallahan18@gmail.com",
           comment = c(ORCID = "0000-0003-1769-7580"))
Description: Simultaneously evaluate multiple ordinal outcome measures. Applied data analysts in particular are faced with uncertainty in choosing appropriate statistical tests for ordinal data. The included 'shiny' application allows users to simulate outcomes given different ordinal data distributions.
License: MIT + file LICENSE
Imports: assertthat, bslib (>= 0.9.0), callr, coin, config (>= 0.3.1),
        dplyr, DT, ggplot2, golem (>= 0.4.0), rhandsontable, rlang,
        rms, shiny (>= 1.7.4), shinycssloaders, shinyWidgets, stats,
        tidyr, utils, withr
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
RoxygenNote: 7.3.2
URL: https://github.com/NeuroShepherd/ordinalsimr,
        https://neuroshepherd.github.io/ordinalsimr/
BugReports: https://github.com/NeuroShepherd/ordinalsimr/issues
Suggests: knitr, pkgload, purrr, rmarkdown, testthat (>= 3.0.0),
        writexl
Config/testthat/edition: 3
Depends: R (>= 4.4.0)
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-02-26 14:45:54 UTC; patcallahan
Author: Pat Callahan [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0003-1769-7580>)
Maintainer: Pat Callahan <patricktcallahan18@gmail.com>
Repository: CRAN
Date/Publication: 2026-02-26 15:10:03 UTC
Built: R 4.6.0; ; 2026-04-29 23:26:33 UTC; unix
