# Generated by roxygen2: do not edit by hand

export("%>%")
export(assign_groups)
export(calculate_power_t2error)
export(calculate_t1_error)
export(get_ordinalsimr_options)
export(ordinal_tests)
export(parse_ratio_text)
export(plot_distribution_results)
export(plot_power)
export(run_app)
export(run_simulations)
export(set_ordinalsimr_options)
import(assertthat)
import(bslib)
import(dplyr)
import(ggplot2)
import(shiny)
import(shinycssloaders)
import(tidyr)
importFrom(dplyr,"%>%")
importFrom(golem,activate_js)
importFrom(golem,add_resource_path)
importFrom(golem,bundle_resources)
importFrom(golem,favicon)
importFrom(golem,with_golem_options)
importFrom(rhandsontable,hot_to_r)
importFrom(rhandsontable,rHandsontableOutput)
importFrom(rhandsontable,renderRHandsontable)
importFrom(rhandsontable,rhandsontable)
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(shiny,NS)
importFrom(shiny,shinyApp)
importFrom(shiny,tagList)
importFrom(shinyWidgets,numericRangeInput)
importFrom(utils,zip)
importFrom(withr,with_seed)
