---
title: "Redesign Layout"
author: "Pat Callahan"
date: "2024-07-18"
output: html_document
---


## Overall Design

Create a page_navbar() with nav_panel() calls for the following pages:

- Home
- Simulation Inputs
- Distributions/Results
- Downloads
  - Data download
  - Report download
  
Add a nav_spacer() after these and then nav_menu() after this for a dropdown menu item. The nav_menu() should contain nav_items() for the website and GitHub links which can look like this roughly:

```r
link_shiny <- tags$a(shiny::icon("github"), "Shiny", href = "https://github.com/rstudio/shiny", target = "_blank")
```
  
### Home

This page can still basically just be the current home page generated by the `homepage.Rmd` and outputting the `homempage.html` HTML fragment available in inst. Should receive some more attention and clean-up, but otherwise this is fine.

### Simulation Inputs

This page should contain a series of cards() or layout_*() functions for the inputs, the rhandsontable, and the DataTables (note `datatable()` has a fill argument, `fillContainer = TRUE`, that I might need to use).

The inputs currently grouped in a box can be combined into a tab or pilltab set up with the Type I error box.

The Add and Delete Row buttons should be moved to their own card grouped alongside the rhandsontable.

Approximation:

* 1/3 of screen width to the inputs tab or pill box
* 2/3 of the screen to the data tables
  - 3/4 of this to the rhandsontable, and 1/4 to the Add/Remove row buttons
* Below the rhandsontable, the tabs for the datatables
  - this could be reimagined/designed as something else or even fully removed
  
### Distributions/Results


* reorganize the inputs and the tables to be on the same row?
* Put the plots in side-by-side cards?

### Downloads


